@@ -20,30 +20,10 @@
  */
 
 #include <goffice/goffice-config.h>
+#include <goffice/gtk/goffice-gtk.h>
 
 #include "go-selector.h"
 
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkarrow.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellview.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkdrawingarea.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkiconview.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkvseparator.h>
-#include <gtk/gtkversion.h>
-
 #include <glib/gi18n-lib.h>
 
 #include <gdk/gdkkeysyms.h>
@@ -57,7 +37,7 @@ static guint 	go_selector_signals[GO_SELECTOR_LAST_SIGNAL] = {0,};
 
 static void     go_selector_finalize   		(GObject *object);
 
-static void 	go_selector_button_toggled 	(GtkWidget *button, 
+static void 	go_selector_button_toggled 	(GtkWidget *button,
 						 gpointer   data);
 static gboolean go_selector_key_press 		(GtkWidget   *widget,
 						 GdkEventKey *event,
@@ -65,12 +45,10 @@ static gboolean go_selector_key_press 		(GtkWidget   *widget,
 static void 	go_selector_popdown 		(GOSelector *selector);
 static void 	go_selector_popup		(GOSelector *selector);
 
-static void 	go_selector_set_active_internal (GOSelector *selector, 
-						 int index, 
+static void 	go_selector_set_active_internal (GOSelector *selector,
+						 int index,
 						 gboolean is_auto);
 
-#define GO_SELECTOR_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GO_TYPE_SELECTOR, GOSelectorPrivate))
-
 struct _GOSelectorPrivate {
 	GtkWidget *button;
 	GtkWidget *box;
@@ -78,7 +56,7 @@ struct _GOSelectorPrivate {
 	GtkWidget *swatch;
 	GtkWidget *separator;
 	GtkWidget *arrow;
-	
+
 	GOPalette *palette;
 
 	gboolean 	 selected_is_auto;
@@ -99,7 +77,7 @@ go_selector_init (GOSelector *selector)
 {
 	GOSelectorPrivate *priv;
 
-	priv = GO_SELECTOR_GET_PRIVATE (selector);
+	priv = G_TYPE_INSTANCE_GET_PRIVATE (selector, GO_TYPE_SELECTOR, GOSelectorPrivate);
 
 	selector->priv = priv;
 
@@ -108,17 +86,17 @@ go_selector_init (GOSelector *selector)
 	priv->selected_is_auto = FALSE;
 
 	gtk_widget_push_composite_child ();
-  
+
 	priv->button = gtk_toggle_button_new ();
 	g_signal_connect (priv->button, "toggled",
 			  G_CALLBACK (go_selector_button_toggled), selector);
-	g_signal_connect_after (priv->button, 
+	g_signal_connect_after (priv->button,
 				"key_press_event",
 				G_CALLBACK (go_selector_key_press), selector);
 	gtk_widget_show (priv->button);
 
-      	priv->box = gtk_hbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (priv->button), 
+	priv->box = gtk_hbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (priv->button),
 			   priv->box);
 	gtk_widget_show (priv->box);
 
@@ -127,7 +105,7 @@ go_selector_init (GOSelector *selector)
 	gtk_box_pack_start (GTK_BOX (priv->box),
 			    priv->alignment, TRUE, TRUE, 0);
 	gtk_widget_show (priv->alignment);
-	
+
 	priv->separator = gtk_vseparator_new ();
 	gtk_box_pack_start (GTK_BOX (priv->box),
 			    priv->separator, FALSE, FALSE, 0);
@@ -139,8 +117,8 @@ go_selector_init (GOSelector *selector)
 	gtk_widget_show (priv->arrow);
 
 	gtk_widget_pop_composite_child ();
-	
-	gtk_box_pack_start (GTK_BOX (selector), priv->button, TRUE, TRUE, 0);	
+
+	gtk_box_pack_start (GTK_BOX (selector), priv->button, TRUE, TRUE, 0);
 
 	priv->dnd_length = 0;
 	priv->dnd_type.target = NULL;
@@ -155,9 +133,9 @@ static void
 go_selector_class_init (GOSelectorClass *class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
-	
+
 	object_class->finalize = go_selector_finalize;
-	
+
 	go_selector_signals[GO_SELECTOR_ACTIVATE] =
 		g_signal_new ("activate",
 			      G_OBJECT_CLASS_TYPE (class),
@@ -210,7 +188,7 @@ cb_palette_deactivate (GOPalette *palette, GOSelector *selector)
  * swatch render function of @palette.
  *
  * Returns: a new #GtkWidget.
- **/ 
+ **/
 GtkWidget *
 go_selector_new (GOPalette *palette)
 {
@@ -220,8 +198,8 @@ go_selector_new (GOPalette *palette)
 	selector = g_object_new (GO_TYPE_SELECTOR, NULL);
 
 	g_return_val_if_fail (GO_IS_PALETTE (palette), selector);
-	
-	priv = GO_SELECTOR_GET_PRIVATE (selector);
+
+	priv = GO_SELECTOR (selector)->priv;
 
 #if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
 	g_object_ref_sink (palette);
@@ -241,79 +219,25 @@ go_selector_new (GOPalette *palette)
 	return selector;
 }
 
-static void
-go_selector_menu_position_below (GtkMenu  *menu,
-				      gint     *x,
-				      gint     *y,
-				      gint     *push_in,
-				      gpointer  user_data)
-{
-	GOSelector *selector = GO_SELECTOR (user_data);
-	gint sx, sy;
-	GtkWidget *widget;
-	GtkRequisition req;
-	GdkScreen *screen;
-	gint monitor_num;
-	GdkRectangle monitor;
-
-	widget = GTK_WIDGET (selector);
-
-	gdk_window_get_origin (widget->window, &sx, &sy);
-
-	if (GTK_WIDGET_NO_WINDOW (widget))
-	{
-		sx += widget->allocation.x;
-		sy += widget->allocation.y;
-	}
-
-	gtk_widget_size_request (GTK_WIDGET (menu), &req);
-
-	if (gtk_widget_get_direction (GTK_WIDGET (selector)) == GTK_TEXT_DIR_LTR)
-		*x = sx;
-	else
-		*x = sx + widget->allocation.width - req.width;
-	*y = sy;
-
-	screen = gtk_widget_get_screen (GTK_WIDGET (selector));
-	monitor_num = gdk_screen_get_monitor_at_window (screen, 
-							GTK_WIDGET (selector)->window);
-	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
-
-	if (*x < monitor.x)
-		*x = monitor.x;
-	else if (*x + req.width > monitor.x + monitor.width)
-		*x = monitor.x + monitor.width - req.width;
-
-	if (monitor.y + monitor.height - *y - widget->allocation.height >= req.height)
-		*y += widget->allocation.height;
-	else if (*y - monitor.y >= req.height)
-		*y -= req.height;
-	else if (monitor.y + monitor.height - *y - widget->allocation.height > *y - monitor.y) 
-		*y += widget->allocation.height;
-	else
-		*y -= req.height;
-
-	*push_in = FALSE;
-}
-
 static void
 go_selector_popup (GOSelector *selector)
 {
 	GOSelectorPrivate *priv;
 
 	g_return_if_fail (GO_IS_SELECTOR (selector));
-	priv = GO_SELECTOR_GET_PRIVATE (selector);
+
+	priv = selector->priv;
 
 	if (!GTK_WIDGET_REALIZED (selector))
 		return;
 
 	if (GTK_WIDGET_MAPPED (priv->palette))
 		return;
-	
+
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->button), TRUE);
 	gtk_menu_popup (GTK_MENU (priv->palette),
-			NULL, NULL, 
-			go_selector_menu_position_below, selector,
+			NULL, NULL,
+			go_menu_position_below, selector,
 			0, 0);
 }
 
@@ -323,7 +247,8 @@ go_selector_popdown (GOSelector *selector)
 	GOSelectorPrivate *priv;
 
 	g_return_if_fail (GO_IS_SELECTOR (selector));
-	priv = GO_SELECTOR_GET_PRIVATE (selector);
+
+	priv = selector->priv;
 
 	gtk_menu_popdown (GTK_MENU (priv->palette));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->button), FALSE);
@@ -333,11 +258,8 @@ static void
 go_selector_button_toggled (GtkWidget *button,
 				 gpointer   data)
 {
-	GOSelectorPrivate *priv;
 	GOSelector *selector = GO_SELECTOR (data);
 
-	priv = GO_SELECTOR_GET_PRIVATE (selector);
-
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
 		go_selector_popup (selector);
 	else
@@ -346,8 +268,8 @@ go_selector_button_toggled (GtkWidget *button,
 
 static gboolean
 go_selector_key_press (GtkWidget   *widget,
-			    GdkEventKey *event,
-			    gpointer     data)
+		       GdkEventKey *event,
+		       gpointer     data)
 {
 	GOSelector *selector = GO_SELECTOR (data);
 	GOSelectorPrivate *priv;
@@ -355,9 +277,9 @@ go_selector_key_press (GtkWidget   *widget,
 	int n_swatches, index;
 	gboolean found = FALSE;
 
-	priv = GO_SELECTOR_GET_PRIVATE (selector);
+	priv = selector->priv;
 
-	if ((event->keyval == GDK_Down || event->keyval == GDK_KP_Down) && 
+	if ((event->keyval == GDK_Down || event->keyval == GDK_KP_Down) &&
 	    state == GDK_MOD1_MASK) {
 		go_selector_popup (selector);
 		return TRUE;
@@ -368,8 +290,8 @@ go_selector_key_press (GtkWidget   *widget,
 
 	n_swatches = go_palette_get_n_swatches (GO_PALETTE (priv->palette));
 	index = 0;
-	
-	switch (event->keyval) 
+
+	switch (event->keyval)
 	{
 		case GDK_Down:
 		case GDK_KP_Down:
@@ -381,7 +303,7 @@ go_selector_key_press (GtkWidget   *widget,
 			/* else fall through */
 		case GDK_Page_Up:
 		case GDK_KP_Page_Up:
-		case GDK_Home: 
+		case GDK_Home:
 		case GDK_KP_Home:
 			if (priv->selected_index != 0) {
 				index = 0;
@@ -396,10 +318,10 @@ go_selector_key_press (GtkWidget   *widget,
 				found = TRUE;
 				break;
 			}
-			/* else fall through */      
+			/* else fall through */
 		case GDK_Page_Down:
 		case GDK_KP_Page_Down:
-		case GDK_End: 
+		case GDK_End:
 		case GDK_KP_End:
 			if (priv->selected_index != n_swatches - 1) {
 				index = n_swatches - 1;
@@ -410,7 +332,7 @@ go_selector_key_press (GtkWidget   *widget,
 			return FALSE;
 	}
 
-	if (found) 
+	if (found)
 		go_selector_set_active_internal (selector, index, FALSE);
 
 	return TRUE;
@@ -424,7 +346,7 @@ go_selector_set_active_internal (GOSelector *selector, int index, gboolean is_au
 	selector->priv->selected_index = index;
 	selector->priv->selected_is_auto = is_auto;
 
-	g_object_set_data (G_OBJECT (selector->priv->swatch), "index", 
+	g_object_set_data (G_OBJECT (selector->priv->swatch), "index",
 			   GINT_TO_POINTER (index));
 
 	go_selector_update_swatch (selector);
@@ -446,13 +368,13 @@ gboolean
 go_selector_set_active (GOSelector *selector, int index)
 {
 	int n_swatches;
-	
+
 	g_return_val_if_fail (GO_IS_SELECTOR (selector), FALSE);
-	
+
 	n_swatches = go_palette_get_n_swatches (GO_PALETTE (selector->priv->palette));
-	
-	if (index != selector->priv->selected_index && 
-	    index >= 0 && 
+
+	if (index != selector->priv->selected_index &&
+	    index >= 0 &&
 	    index < n_swatches) {
 		go_selector_set_active_internal (selector, index, FALSE);
 		return TRUE;
@@ -463,7 +385,7 @@ go_selector_set_active (GOSelector *selector, int index)
 /**
  * go_selector_get_active:
  * @selector: a #GOSelector
- * @is_auto :
+ * @is_auto : boolean
  *
  * Retrieves current selection index, and set @is_auto to TRUE if
  * current selection was set by clicking on automatic palette item.
@@ -519,12 +441,12 @@ go_selector_activate (GOSelector *selector)
  *
  * Returns: a pointer to palette user_data.
  **/
-gpointer 	 
+gpointer
 go_selector_get_user_data (GOSelector *selector)
 {
 	g_return_val_if_fail (GO_IS_SELECTOR (selector), NULL);
 
-	return go_palette_get_user_data (GO_PALETTE (selector->priv->palette));	
+	return go_palette_get_user_data (GO_PALETTE (selector->priv->palette));
 }
 
 static void
@@ -540,7 +462,7 @@ go_selector_drag_data_received (GtkWidget        *button,
 	GOSelectorPrivate *priv = selector->priv;
 
 	if (selection_data->length != priv->dnd_length ||
-	    priv->dnd_data_received == NULL) 
+	    priv->dnd_data_received == NULL)
 		return;
 
 	(priv->dnd_data_received) (selector, selection_data->data);
@@ -581,7 +503,7 @@ go_selector_drag_data_get (GtkWidget        *button,
 		return;
 
 	data = (priv->dnd_data_get) (selector);
-	
+
 	if (data != NULL) {
 		gtk_selection_data_set (selection_data, selection_data->target,
 					8, data, priv->dnd_length);
@@ -611,7 +533,7 @@ go_selector_setup_dnd (GOSelector *selector,
 	GOSelectorPrivate *priv;
 
 	g_return_if_fail (GO_IS_SELECTOR (selector));
-	
+
 	priv = selector->priv;
 	g_return_if_fail (!priv->dnd_initialized);
 	g_return_if_fail (dnd_length > 0);
@@ -631,7 +553,7 @@ go_selector_setup_dnd (GOSelector *selector,
 	gtk_drag_source_set (priv->button,
 			     GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
 			     &priv->dnd_type, 1, GDK_ACTION_COPY);
-	
+
 	g_signal_connect (priv->button, "drag_begin",
 			  G_CALLBACK (go_selector_drag_begin), selector);
 	g_signal_connect (priv->button, "drag_data_received",
