@@ -23,7 +23,6 @@
 #include "gog-xy.h"
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-error-bar.h>
@@ -31,12 +30,15 @@
 #include <goffice/graph/gog-chart-map.h>
 #include <goffice/graph/gog-series-lines.h>
 #include <goffice/data/go-data.h>
+#include <goffice/data/go-data-simple.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-marker.h>
 #include <goffice/utils/go-format.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-line.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 #include <goffice/app/module-plugin-defs.h>
 
 #ifdef GOFFICE_WITH_GTK
@@ -98,30 +100,26 @@ gog_2d_plot_update (GogObject *obj)
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
 
-		go_data_vector_get_minmax (GO_DATA_VECTOR (
-			series->base.values[1].data), &tmp_min, &tmp_max);
+		go_data_get_bounds (series->base.values[1].data, &tmp_min, &tmp_max);
 		if (y_min > tmp_min) y_min = tmp_min;
 		if (y_max < tmp_max) y_max = tmp_max;
 		if (model->y.fmt == NULL)
 			model->y.fmt = go_data_preferred_fmt (series->base.values[1].data);
 
 		if (series->base.values[0].data != NULL) {
-			go_data_vector_get_minmax (GO_DATA_VECTOR (
-				series->base.values[0].data), &tmp_min, &tmp_max);
+			go_data_get_bounds (series->base.values[0].data, &tmp_min, &tmp_max);
 
 			if (!go_finite (tmp_min) || !go_finite (tmp_max) ||
 			    tmp_min > tmp_max) {
 				tmp_min = 0;
-				tmp_max = go_data_vector_get_len (
-					GO_DATA_VECTOR (series->base.values[1].data));
+				tmp_max = go_data_get_vector_size (series->base.values[1].data);
 
 				is_discrete = TRUE;
 			} else if (model->x.fmt == NULL)
 				model->x.fmt = go_data_preferred_fmt (series->base.values[0].data);
 		} else {
 			tmp_min = 0;
-			tmp_max = go_data_vector_get_len (
-				GO_DATA_VECTOR (series->base.values[1].data));
+			tmp_max = go_data_get_vector_size (series->base.values[1].data);
 			is_discrete = TRUE;
 		}
 
@@ -232,7 +230,6 @@ gog_2d_plot_class_init (GogPlotClass *plot_klass)
 	gog_klass->update	= gog_2d_plot_update;
 	gog_klass->view_type	= gog_xy_view_get_type ();
 
-	plot_klass->desc.num_series_min = 1;
 	plot_klass->desc.num_series_max = G_MAXINT;
 	plot_klass->series_type  	= gog_xy_series_get_type ();
 	plot_klass->axis_set	      	= GOG_AXIS_SET_XY;
@@ -248,7 +245,7 @@ gog_2d_plot_init (Gog2DPlot *plot2d)
 
 GSF_DYNAMIC_CLASS (Gog2DPlot, gog_2d_plot,
 	gog_2d_plot_class_init, gog_2d_plot_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 enum {
 	GOG_XY_PROP_0,
@@ -260,7 +257,7 @@ enum {
 
 static GogObjectClass *xy_parent_klass;
 
-#define GOG_XY_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_XY_PLOT_TYPE, GogXYPlotClass))
+#define GOG_XY_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_XY_PLOT, GogXYPlotClass))
 
 static char const *
 gog_xy_plot_type_name (G_GNUC_UNUSED GogObject const *item)
@@ -382,10 +379,10 @@ gog_xy_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_LINE 
-			| GOG_STYLE_FILL 
-			| GOG_STYLE_MARKER 
-			| GOG_STYLE_INTERPOLATION;
+		plot_klass->desc.series.style_fields = GO_STYLE_LINE 
+			| GO_STYLE_FILL 
+			| GO_STYLE_MARKER 
+			| GO_STYLE_INTERPOLATION;
 	}
 }
 
@@ -405,7 +402,7 @@ GSF_DYNAMIC_CLASS (GogXYPlot, gog_xy_plot,
 
 static GogObjectClass *bubble_parent_klass;
 
-#define GOG_BUBBLE_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_BUBBLE_PLOT_TYPE, GogBubblePlotClass))
+#define GOG_BUBBLE_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_BUBBLE_PLOT, GogBubblePlotClass))
 
 static void gog_bubble_plot_adjust_bounds (Gog2DPlot *model, double *x_min, double *x_max, double *y_min, double *y_max);
 
@@ -418,11 +415,11 @@ gog_bubble_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 extern gpointer gog_bubble_plot_pref (GogBubblePlot *bubble, GOCmdContext *cc);
 static void
 gog_bubble_plot_populate_editor (GogObject *obj, 
-				 GogEditor *editor,
+				 GOEditor *editor,
 				 G_GNUC_UNUSED GogDataAllocator *dalloc,
 			GOCmdContext *cc)
 {
-	gog_editor_add_page (editor,
+	go_editor_add_page (editor,
 			     gog_bubble_plot_pref (GOG_BUBBLE_PLOT (obj), cc),
 			     _("Properties"));
 
@@ -551,7 +548,7 @@ gog_bubble_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+		plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	}
 }
 
@@ -595,7 +592,7 @@ enum {
 
 static GogObjectClass *map_parent_klass;
 
-#define GOG_XY_COLOR_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_XY_COLOR_PLOT_TYPE, GogXYColorPlotClass))
+#define GOG_XY_COLOR_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_XY_COLOR_PLOT, GogXYColorPlotClass))
 
 static void
 gog_xy_color_plot_clear_formats (GogXYColorPlot *map)
@@ -622,8 +619,7 @@ gog_xy_color_plot_update (GogObject *obj)
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
 
-		go_data_vector_get_minmax (GO_DATA_VECTOR (
-			series->base.values[2].data), &tmp_min, &tmp_max);
+		go_data_get_bounds (series->base.values[2].data, &tmp_min, &tmp_max);
 		if (z_min > tmp_min) z_min = tmp_min;
 		if (z_max < tmp_max) z_max = tmp_max;
 		if (model->z.fmt == NULL)
@@ -675,7 +671,7 @@ hide_outliers_toggled_cb (GtkToggleButton *btn, GObject *obj)
 
 static void 
 gog_xy_color_plot_populate_editor (GogObject *obj,
-				   GogEditor *editor,
+				   GOEditor *editor,
 				   GogDataAllocator *dalloc,
 				   GOCmdContext *cc)
 {
@@ -686,7 +682,7 @@ gog_xy_color_plot_populate_editor (GogObject *obj,
 
 	dir = go_plugin_get_dir_name (go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
 	path = g_build_filename (dir, "gog-xy-color-prefs.glade", NULL);
-	gui = go_libglade_new (path, "gog-xy-color-prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new (path, "gog-xy-color-prefs", GETTEXT_PACKAGE, cc);
 	g_free (path);
 
 	if (gui != NULL) {
@@ -697,7 +693,8 @@ gog_xy_color_plot_populate_editor (GogObject *obj,
 			"toggled",
 			G_CALLBACK (hide_outliers_toggled_cb), obj);
 		w = glade_xml_get_widget (gui, "gog-xy-color-prefs");
-		gog_editor_add_page (editor, w, _("Properties"));
+		go_editor_add_page (editor, w, _("Properties"));
+		g_object_unref (gui);
 	}
 
 #endif
@@ -808,8 +805,8 @@ gog_xy_color_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_LINE | GOG_STYLE_MARKER
-			| GOG_STYLE_INTERPOLATION |GOG_STYLE_MARKER_NO_COLOR;
+		plot_klass->desc.series.style_fields = GO_STYLE_LINE | GO_STYLE_MARKER
+			| GO_STYLE_INTERPOLATION |GO_STYLE_MARKER_NO_COLOR;
 	}
 	plot_klass->axis_set	      	= GOG_AXIS_SET_XY_COLOR;
 	plot_klass->axis_get_bounds   	= gog_xy_color_plot_axis_get_bounds;
@@ -866,8 +863,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogXYSeries const *series = NULL;
 	unsigned i ,j ,k ,n;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (model));
-	GogStyle *neg_style = NULL;
-	GogStyle *style = NULL;
+	GOStyle *neg_style = NULL;
+	GOStyle *style = NULL;
 	GogViewAllocation const *area;
 	GOPath *path = NULL, *next_path = NULL;
 	GSList *ptr;
@@ -908,12 +905,10 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 		hide_outliers = GOG_XY_COLOR_PLOT (model)->hide_outliers;
 	}
 
-	/* Draw drop lines from point to axis start. To change this behaviour
-	 * and draw drop lines from point to zero, we can use gog_axis_map_get_baseline:
-	 * x_bottom = gog_axis_map_get_baseline (x_map); 
-	 * What we really want is to draw drop lines from point to
+	/* What we really want is to draw drop lines from point to
 	 * a selected axis. But for this purpose, we need a GogAxisBase selector in
-	 * GogSeriesLine, which doesn't really know what it's supposed to do with it. */
+	 * GogSeriesLines (we might actually need GogDropLines. For now just let
+	 * the drop lines go the the axis. */
 
 	gog_axis_map_get_extents (x_map, &x_left, &x_right);
 	x_left = gog_axis_map_to_view (x_map, x_left);
@@ -945,14 +940,14 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 		if (n < 1)
 			continue;
 
-		style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+		style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 
-		show_marks = gog_style_is_marker_visible (style);
-		show_lines = gog_style_is_line_visible (style);
-		show_fill = gog_style_is_fill_visible (style);
+		show_marks = go_style_is_marker_visible (style);
+		show_lines = go_style_is_line_visible (style);
+		show_fill = go_style_is_fill_visible (style);
 
 		if (model->base.vary_style_by_element)
-			style = gog_style_dup (style);
+			style = go_style_dup (style);
 		gog_renderer_push_style (view->renderer, style);
 
 		if ((show_lines || show_fill) && !GOG_IS_BUBBLE_PLOT (model)) {
@@ -960,11 +955,15 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				path = next_path;
 			else
 				path = gog_chart_map_make_path (chart_map, x_vals, y_vals,
-								n, series->base.interpolation);
+								n, series->base.interpolation,
+								series->base.interpolation_skip_invalid,
+								&series->clamped_derivs);
 
 			next_path = NULL;
 
-			if (series->base.fill_type != GOG_SERIES_FILL_TYPE_NEXT) {
+			if (series->base.interpolation == GO_LINE_INTERPOLATION_CLOSED_SPLINE)
+				gog_renderer_fill_serie	(view->renderer, path, NULL);
+			else if (series->base.fill_type != GOG_SERIES_FILL_TYPE_NEXT) {
 				GOPath *close_path;
 
 				close_path = gog_chart_map_make_close_path (chart_map, x_vals, y_vals, n,
@@ -978,19 +977,21 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 
 					next_series = ptr->next->data;
 					if (gog_series_is_valid (GOG_SERIES (next_series))) {
-						GogStyle *next_style;
+						GOStyle *next_style;
 						const double *next_x_vals, *next_y_vals;
 						unsigned int next_n_points;
 
 						next_n_points = gog_series_get_xy_data
 							(GOG_SERIES (next_series),
 							 &next_x_vals, &next_y_vals);
-						next_style = gog_styled_object_get_style
-							(GOG_STYLED_OBJECT (next_series));
+						next_style = go_styled_object_get_style
+							(GO_STYLED_OBJECT (next_series));
 
 						next_path = gog_chart_map_make_path
 							(chart_map, next_x_vals, next_y_vals,
-							 next_n_points, next_series->base.interpolation);
+							 next_n_points, next_series->base.interpolation,
+							 series->base.interpolation_skip_invalid,
+							 &series->clamped_derivs);
 
 					}
 				}
@@ -1000,10 +1001,34 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 
 		if (series->hdroplines) {
 			GOPath *drop_path;
-			double y_drop;
-
+			double y_drop, x_target;
+			GogAxis *axis = GOG_PLOT (model)->axis[GOG_AXIS_Y];
+			GogAxisPosition pos = gog_axis_base_get_clamped_position (GOG_AXIS_BASE (axis));
+			switch (pos) {
+			case GOG_AXIS_AT_LOW:
+				x_target = gog_axis_map_is_inverted (x_map)? x_right: x_left;
+				break;
+			case GOG_AXIS_CROSS: {
+				GogChartMap *c_map;
+				GogAxisMap *a_map;
+				c_map = gog_chart_map_new (chart, area, axis,
+						gog_axis_base_get_crossed_axis (GOG_AXIS_BASE (axis)),
+						NULL, FALSE);
+				a_map = gog_chart_map_get_axis_map (c_map, 1);
+				x_target = gog_axis_map_to_view (a_map, gog_axis_base_get_cross_location (GOG_AXIS_BASE (axis)));
+				gog_chart_map_free (c_map);
+				break;
+			}
+			case GOG_AXIS_AT_HIGH:
+				x_target = gog_axis_map_is_inverted (x_map)? x_left: x_right;
+				break;
+			default:
+				/* this should not occur */
+				x_target = gog_axis_map_to_view (x_map, 0);
+				break;
+			}
 			gog_renderer_push_style (view->renderer,
-				gog_styled_object_get_style (GOG_STYLED_OBJECT (series->hdroplines)));
+				go_styled_object_get_style (GO_STYLED_OBJECT (series->hdroplines)));
 			drop_path = go_path_new ();
 			go_path_set_options (drop_path, GO_PATH_OPTIONS_SHARP);
 			for (i = 0; i < n; i++) {
@@ -1013,7 +1038,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				if (!gog_axis_map_finite (x_map, x))
 					continue;
 				y_drop = gog_axis_map_to_view (y_map, y_vals[i]);
-				go_path_move_to (drop_path, x_left, y_drop);
+				go_path_move_to (drop_path, x_target, y_drop);
 				go_path_line_to (drop_path, gog_axis_map_to_view (x_map, x), y_drop);
 			}
 			gog_renderer_stroke_serie (view->renderer, drop_path);
@@ -1023,10 +1048,34 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 
 		if (series->vdroplines) {
 			GOPath *drop_path;
-			double x_drop;
-
+			double x_drop, y_target;
+			GogAxis *axis = GOG_PLOT (model)->axis[GOG_AXIS_X];
+			GogAxisPosition pos = gog_axis_base_get_clamped_position (GOG_AXIS_BASE (axis));
+			switch (pos) {
+			case GOG_AXIS_AT_LOW:
+				y_target = gog_axis_map_is_inverted (y_map)? y_top: y_bottom;
+				break;
+			case GOG_AXIS_CROSS: {
+				GogChartMap *c_map;
+				GogAxisMap *a_map;
+				c_map = gog_chart_map_new (chart, area, axis,
+						gog_axis_base_get_crossed_axis (GOG_AXIS_BASE (axis)),
+						NULL, FALSE);
+				a_map = gog_chart_map_get_axis_map (c_map, 1);
+				y_target = gog_axis_map_to_view (a_map, gog_axis_base_get_cross_location (GOG_AXIS_BASE (axis)));
+				gog_chart_map_free (c_map);
+				break;
+			}
+			case GOG_AXIS_AT_HIGH:
+				y_target = gog_axis_map_is_inverted (y_map)? y_bottom: y_top;
+				break;
+			default:
+				/* this should not occur */
+				y_target = gog_axis_map_to_view (y_map, 0);
+				break;
+			}
 			gog_renderer_push_style (view->renderer,
-				gog_styled_object_get_style (GOG_STYLED_OBJECT (series->vdroplines)));
+				go_styled_object_get_style (GO_STYLED_OBJECT (series->vdroplines)));
 			drop_path = go_path_new ();
 			go_path_set_options (drop_path, GO_PATH_OPTIONS_SHARP);
 			for (i = 0; i < n; i++) {
@@ -1036,7 +1085,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				if (!gog_axis_map_finite (x_map, x))
 					continue;
 				x_drop = gog_axis_map_to_view (x_map, x);
-				go_path_move_to (drop_path, x_drop, y_bottom);
+				go_path_move_to (drop_path, x_drop, y_target);
 				go_path_line_to (drop_path, x_drop, gog_axis_map_to_view (y_map, y_vals[i]));
 			}
 			gog_renderer_stroke_serie (view->renderer, drop_path);
@@ -1051,7 +1100,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 
 		if (GOG_IS_BUBBLE_PLOT (model)) {
 			double zmin;
-			go_data_vector_get_minmax (GO_DATA_VECTOR (series->base.values[2].data), &zmin, &zmax);
+			go_data_get_bounds (series->base.values[2].data, &zmin, &zmax);
 			show_negatives = GOG_BUBBLE_PLOT (view->model)->show_negatives;
 			if ((! go_finite (zmax)) || (!show_negatives && (zmax <= 0))) continue;
 			rmax = MIN (view->residual.w, view->residual.h) / BUBBLE_MAX_RADIUS_RATIO
@@ -1061,8 +1110,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 			if (show_negatives) {
 				zmin = fabs (zmin);
 				if (zmin > zmax) zmax = zmin;
-				neg_style = gog_style_dup (GOG_STYLED_OBJECT (series)->style);
-				neg_style->fill.type = GOG_FILL_STYLE_PATTERN;
+				neg_style = go_style_dup (GOG_STYLED_OBJECT (series)->style);
+				neg_style->fill.type = GO_STYLE_FILL_PATTERN;
 				neg_style->fill.pattern.pattern = GO_PATTERN_SOLID;
 				neg_style->fill.pattern.back = RGBA_WHITE;
 			}
@@ -1115,8 +1164,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 							gse = GOG_SERIES_ELEMENT (overrides->data);
 							overrides = overrides->next;
 							gog_renderer_push_style (view->renderer,
-								gog_styled_object_get_style (
-									GOG_STYLED_OBJECT (gse)));
+								go_styled_object_get_style (
+									GO_STYLED_OBJECT (gse)));
 					} else if (model->base.vary_style_by_element)
 						gog_theme_fillin_style (theme, style, GOG_OBJECT (series),
 									model->base.index_num + i - 1, FALSE);
@@ -1193,7 +1242,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 							(GOG_SERIES_ELEMENT (overrides->data)->index == k)) {
 								gse = GOG_SERIES_ELEMENT (overrides->data);
 								overrides = overrides->next;
-								style = gog_styled_object_get_style (GOG_STYLED_OBJECT (gse));
+								style = go_styled_object_get_style (GO_STYLED_OBJECT (gse));
 								gog_renderer_push_style (view->renderer, style);
 						}
 						if (is_map) {
@@ -1249,16 +1298,16 @@ gog_xy_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogXYView, gog_xy_view,
 	gog_xy_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
 
 /*****************************************************************************/
 
 typedef GogView		GogXYSeriesView;
 typedef GogViewClass	GogXYSeriesViewClass;
 
-#define GOG_XY_SERIES_VIEW_TYPE	(gog_xy_series_view_get_type ())
-#define GOG_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_SERIES_VIEW_TYPE, GogXYSeriesView))
-#define IS_GOG_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_SERIES_VIEW_TYPE))
+#define GOG_TYPE_XY_SERIES_VIEW	(gog_xy_series_view_get_type ())
+#define GOG_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_SERIES_VIEW, GogXYSeriesView))
+#define GOG_IS_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_SERIES_VIEW))
 
 static void
 gog_xy_series_view_render (GogView *view, GogViewAllocation const *bbox)
@@ -1288,7 +1337,7 @@ gog_xy_series_view_class_init (GogXYSeriesViewClass *gview_klass)
 
 GSF_DYNAMIC_CLASS (GogXYSeriesView, gog_xy_series_view,
 	gog_xy_series_view_class_init, NULL,
-	GOG_VIEW_TYPE)
+	GOG_TYPE_VIEW)
 
 /*****************************************************************************/
 
@@ -1342,22 +1391,22 @@ vert_drop_lines_pre_remove (GogObject *parent, GogObject *child)
 
 typedef GogSeriesElement GogXYSeriesElement;
 typedef GogSeriesElementClass GogXYSeriesElementClass;
-#define GOG_XY_SERIES_ELEMENT_TYPE	(gog_xy_series_element_get_type ())
-#define GOG_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_SERIES_ELEMENT_TYPE, GogXYSeriesElement))
-#define IS_GOG_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_SERIES_ELEMENT_TYPE))
+#define GOG_TYPE_XY_SERIES_ELEMENT	(gog_xy_series_element_get_type ())
+#define GOG_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_SERIES_ELEMENT, GogXYSeriesElement))
+#define GOG_IS_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_SERIES_ELEMENT))
 GType gog_xy_series_element_get_type (void);
 
 static void
-gog_xy_series_element_init_style (GogStyledObject *gso, GogStyle *style)
+gog_xy_series_element_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries const *series = GOG_SERIES (GOG_OBJECT (gso)->parent);
-	GogStyle *parent_style;
+	GOStyle *parent_style;
 
 	g_return_if_fail (series != NULL);
 
-	parent_style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
-	if (parent_style->interesting_fields & GOG_STYLE_MARKER)
-		style->interesting_fields = parent_style->interesting_fields & (GOG_STYLE_MARKER | GOG_STYLE_MARKER_NO_COLOR);
+	parent_style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
+	if (parent_style->interesting_fields & GO_STYLE_MARKER)
+		style->interesting_fields = parent_style->interesting_fields & (GO_STYLE_MARKER | GO_STYLE_MARKER_NO_COLOR);
 	else
 		style->interesting_fields = parent_style->interesting_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
@@ -1373,7 +1422,87 @@ gog_xy_series_element_class_init (GogXYSeriesElementClass *klass)
 
 GSF_DYNAMIC_CLASS (GogXYSeriesElement, gog_xy_series_element,
 	gog_xy_series_element_class_init, NULL,
-	GOG_SERIES_ELEMENT_TYPE)
+	GOG_TYPE_SERIES_ELEMENT)
+
+/****************************************************************************/
+
+typedef struct {
+	GogObject base;
+	GogXYSeries *series;
+	GogDatasetElement *derivs;
+} GogXYInterpolationClamps;
+
+typedef GogObjectClass GogXYInterpolationClampsClass;
+
+#define GOG_TYPE_XY_INTERPOLATION_CLAMPS	(gog_xy_interpolation_clamps_get_type ())
+#define GOG_XY_INTERPOLATION_CLAMPS(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_INTERPOLATION_CLAMPS, GogXYInterpolationClamps))
+#define GOG_IS_XY_INTERPOLATION_CLAMPS(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_INTERPOLATION_CLAMPS))
+GType gog_xy_interpolation_clamps_get_type (void);
+
+static GObjectClass *interp_parent_klass;
+
+static void
+gog_xy_interpolation_clamps_dataset_dims (GogDataset const *set, int *first, int *last)
+{
+	*first = 0;
+	*last = 1;
+}
+
+static GogDatasetElement *
+gog_xy_interpolation_clamps_dataset_get_elem (GogDataset const *set, int dim_i)
+{
+	GogXYInterpolationClamps *clamps = GOG_XY_INTERPOLATION_CLAMPS (set);
+	g_return_val_if_fail (2 > dim_i, NULL);
+	g_return_val_if_fail (dim_i >= 0, NULL);
+	return clamps->derivs + dim_i;
+}
+
+static void
+gog_xy_interpolation_clamps_dataset_dim_changed (GogDataset *set, int dim_i)
+{
+	GogXYInterpolationClamps *clamps = GOG_XY_INTERPOLATION_CLAMPS (set);
+	clamps->series->clamped_derivs[dim_i] = (GO_IS_DATA ((clamps->derivs + dim_i)->data))?
+		go_data_get_scalar_value ((clamps->derivs + dim_i)->data): 0.;
+	gog_object_request_update (GOG_OBJECT (clamps->series));
+}
+
+static void
+gog_xy_interpolation_clamps_dataset_init (GogDatasetClass *iface)
+{
+	iface->get_elem	   = gog_xy_interpolation_clamps_dataset_get_elem;
+	iface->dims	   = gog_xy_interpolation_clamps_dataset_dims;
+	iface->dim_changed = gog_xy_interpolation_clamps_dataset_dim_changed;
+}
+
+static void
+gog_xy_interpolation_clamps_finalize (GObject *obj)
+{
+	GogXYInterpolationClamps *clamps = GOG_XY_INTERPOLATION_CLAMPS (obj);
+	if (clamps->derivs != NULL) {
+		gog_dataset_finalize (GOG_DATASET (obj));
+		g_free (clamps->derivs);
+		clamps->derivs = NULL;
+	}
+	(*interp_parent_klass->finalize) (obj);
+}
+
+static void
+gog_xy_interpolation_clamps_class_init (GObjectClass *klass)
+{
+	interp_parent_klass = g_type_class_peek_parent (klass);
+	klass->finalize	    = gog_xy_interpolation_clamps_finalize;
+}
+
+static void
+gog_xy_interpolation_clamps_init (GogXYInterpolationClamps *clamps)
+{
+	clamps->derivs = g_new0 (GogDatasetElement, 2);
+}
+
+GSF_CLASS_FULL (GogXYInterpolationClamps, gog_xy_interpolation_clamps,
+		NULL, NULL, gog_xy_interpolation_clamps_class_init, NULL,
+		gog_xy_interpolation_clamps_init, GOG_TYPE_OBJECT, 0,
+		GSF_INTERFACE (gog_xy_interpolation_clamps_dataset_init, GOG_TYPE_DATASET))
 
 /****************************************************************************/
 
@@ -1383,11 +1512,21 @@ enum {
 	SERIES_PROP_0,
 	SERIES_PROP_XERRORS,
 	SERIES_PROP_YERRORS,
-	SERIES_PROP_INVALID_AS_ZERO
+	SERIES_PROP_INVALID_AS_ZERO,
+	SERIES_PROP_CLAMP0,
+	SERIES_PROP_CLAMP1
 };
 
 static GogStyledObjectClass *series_parent_klass;
 
+static GogDataset *
+gog_xy_series_get_interpolation_params (GogSeries const *series)
+{
+	GogXYSeries *xy = GOG_XY_SERIES (series);
+	g_return_val_if_fail (xy, NULL);
+	return xy->interpolation_props;
+}
+
 static void
 gog_xy_series_update (GogObject *obj)
 {
@@ -1405,7 +1544,7 @@ gog_xy_series_update (GogObject *obj)
 
 	/* update children */
 	for (ptr = obj->children; ptr != NULL; ptr = ptr->next)
-		if (!IS_GOG_SERIES_LINES (ptr->data))
+		if (!GOG_IS_SERIES_LINES (ptr->data))
 			gog_object_request_update (GOG_OBJECT (ptr->data));
 
 	/* queue plot for redraw */
@@ -1426,6 +1565,10 @@ gog_xy_series_init (GObject *obj)
 	(GOG_SERIES (series))->acceptable_children = GOG_SERIES_ACCEPT_TREND_LINE;
 	series->x_errors = series->y_errors = NULL;
 	series->hdroplines = series->vdroplines = NULL;
+	series->interpolation_props = g_object_new (GOG_TYPE_XY_INTERPOLATION_CLAMPS, NULL);
+	GOG_XY_INTERPOLATION_CLAMPS (series->interpolation_props)->series = series;
+	gog_dataset_set_dim (series->interpolation_props, 0, go_data_scalar_val_new (0.), NULL);
+	gog_dataset_set_dim (series->interpolation_props, 1, go_data_scalar_val_new (0.), NULL);
 }
 
 static void
@@ -1443,11 +1586,16 @@ gog_xy_series_finalize (GObject *obj)
 		series->y_errors = NULL;
 	}
 
+	if (series->interpolation_props != NULL) {
+		g_object_unref (series->interpolation_props);
+		series->interpolation_props = NULL;
+	}
+
 	G_OBJECT_CLASS (series_parent_klass)->finalize (obj);
 }
 
 static void
-gog_xy_series_init_style (GogStyledObject *gso, GogStyle *style)
+gog_xy_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries *series = GOG_SERIES (gso);
 
@@ -1466,7 +1614,7 @@ gog_xy_series_init_style (GogStyledObject *gso, GogStyle *style)
 			style->line.dash_type = GO_LINE_NONE;
 
 		if (!plot->default_style_has_fill && style->fill.auto_type)
-			style->fill.type = GOG_FILL_STYLE_NONE;
+			style->fill.type = GO_STYLE_FILL_NONE;
 
 		if (plot->use_splines)
 			series->interpolation = GO_LINE_INTERPOLATION_SPLINE;
@@ -1476,7 +1624,7 @@ gog_xy_series_init_style (GogStyledObject *gso, GogStyle *style)
 			style->line.dash_type = GO_LINE_NONE;
 
 		if (!plot->default_style_has_fill && style->fill.auto_type)
-			style->fill.type = GOG_FILL_STYLE_NONE;
+			style->fill.type = GO_STYLE_FILL_NONE;
 	}
 }
 
@@ -1528,6 +1676,14 @@ gog_xy_series_set_property (GObject *obj, guint param_id,
 		series->invalid_as_zero = g_value_get_boolean (value);
 		gog_object_request_update (GOG_OBJECT (series));
 		break;
+	case SERIES_PROP_CLAMP0:
+		gog_dataset_set_dim (series->interpolation_props, 0,
+				     go_data_scalar_val_new (g_value_get_double (value)), NULL);
+		break;
+	case SERIES_PROP_CLAMP1:
+		gog_dataset_set_dim (series->interpolation_props, 1,
+				     go_data_scalar_val_new (g_value_get_double (value)), NULL);
+		break;
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
 	}
@@ -1549,6 +1705,12 @@ gog_xy_series_get_property (GObject *obj, guint param_id,
 	case SERIES_PROP_INVALID_AS_ZERO:
 		g_value_set_boolean (value, series->invalid_as_zero);
 		break;
+	case SERIES_PROP_CLAMP0:
+		g_value_set_double (value, series->clamped_derivs[0]);
+		break;
+	case SERIES_PROP_CLAMP1:
+		g_value_set_double (value, series->clamped_derivs[1]);
+		break;
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
 	}
@@ -1563,7 +1725,7 @@ invalid_toggled_cb (GtkToggleButton *btn, GObject *obj)
 
 static void
 gog_xy_series_populate_editor (GogObject *obj,
-			       GogEditor *editor,
+			       GOEditor *editor,
 			       GogDataAllocator *dalloc,
 			       GOCmdContext *cc)
 {
@@ -1572,7 +1734,7 @@ gog_xy_series_populate_editor (GogObject *obj,
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
 	char *path = g_build_filename (dir, "gog-xy-series-prefs.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_xy_series_prefs", GETTEXT_PACKAGE, cc);
+	GladeXML *gui = go_glade_new (path, "gog_xy_series_prefs", GETTEXT_PACKAGE, cc);
 
 	g_free (path);
 
@@ -1591,13 +1753,13 @@ gog_xy_series_populate_editor (GogObject *obj,
 		g_object_set_data_full (G_OBJECT (w),
 			"state", gui, (GDestroyNotify)g_object_unref);
 
-		gog_editor_add_page (editor, w, _("Details"));
+		go_editor_add_page (editor, w, _("Details"));
 	}
 
 	w = gog_error_bar_prefs (GOG_SERIES (obj), "x-errors", TRUE, dalloc, cc);
-	gog_editor_add_page (editor, w, _("X error bars"));
+	go_editor_add_page (editor, w, _("X error bars"));
 	w = gog_error_bar_prefs (GOG_SERIES (obj), "y-errors", FALSE, dalloc, cc);
-	gog_editor_add_page (editor, w, _("Y error bars"));
+	go_editor_add_page (editor, w, _("Y error bars"));
 }
 #endif
 
@@ -1653,7 +1815,8 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 
 	series_klass->has_interpolation = TRUE;
 	series_klass->has_fill_type	= TRUE;
-	series_klass->series_element_type = GOG_XY_SERIES_ELEMENT_TYPE;
+	series_klass->series_element_type = GOG_TYPE_XY_SERIES_ELEMENT;
+	series_klass->get_interpolation_params = gog_xy_series_get_interpolation_params;
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
@@ -1661,13 +1824,13 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 		g_param_spec_object ("x-errors", 
 			_("X error bars"),
 			_("GogErrorBar *"),
-			GOG_ERROR_BAR_TYPE, 
+			GOG_TYPE_ERROR_BAR, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_YERRORS,
 		g_param_spec_object ("y-errors", 
 			_("Y error bars"),
 			_("GogErrorBar *"),
-			GOG_ERROR_BAR_TYPE, 
+			GOG_TYPE_ERROR_BAR, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_INVALID_AS_ZERO,
 		g_param_spec_boolean ("invalid-as-zero", 
@@ -1675,13 +1838,25 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 			_("Replace invalid values by 0 when drawing markers or bubbles"),
 			FALSE, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, SERIES_PROP_CLAMP0,
+		g_param_spec_double ("clamp0", 
+			_("Clamp at start"),
+			_("Slope at start of the interpolated curve when using clamped spline interpolation"),
+			-G_MAXDOUBLE, G_MAXDOUBLE, 0.,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, SERIES_PROP_CLAMP1,
+		g_param_spec_double ("clamp1", 
+			_("Clamp at end"),
+			_("Slope at end of the interpolated curve when using clamped spline interpolation"),
+			-G_MAXDOUBLE, G_MAXDOUBLE, 0.,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	series_klass->valid_fill_type_list = valid_fill_type_list;
 }
 
 GSF_DYNAMIC_CLASS (GogXYSeries, gog_xy_series,
 	gog_xy_series_class_init, gog_xy_series_init,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
 
 G_MODULE_EXPORT void
 go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
